Exception: Shojiku::AbiMismatch
- Defined in:
- lib/shojiku/errors.rb
Overview
The library loaded but implements a different ABI revision than this gem was written against. Loading anyway would mean calling symbols whose meaning has changed.
The library loaded but implements a different ABI revision than this gem was written against. Loading anyway would mean calling symbols whose meaning has changed.